@@ -7,9 +7,9 @@
 (in-package :creole)
 
 (defvar *data-dir* 
-  (make-pathname 
-   :directory (pathname-directory 
-	       (merge-pathnames #P"data/" *load-pathname*))))
+  #.(make-pathname 
+     :directory (pathname-directory 
+		 (merge-pathnames #P"data/" (or *compile-file-pathname* *load-pathname*)))))
 						       
 (deftype octet () '(unsigned-byte 8))
 (deftype simple-octets () '(simple-array octet))
@@ -19,4 +19,4 @@
                                       #-SBCL 'array-index)
 
 (defparameter *fastest*   '(optimize (speed 3) (debug 0) (safety 0) (compilation-speed 0)))
-(defparameter *interface* '(optimize (speed 3) (debug 1) (safety 1) (compilation-speed 0)))
\ No newline at end of file
+(defparameter *interface* '(optimize (speed 3) (debug 1) (safety 1) (compilation-speed 0)))
